'use strict';
/** @jsx element */

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.name = undefined;
exports.initialState = initialState;
exports.render = render;
exports.afterRender = afterRender;
exports.afterUpdate = afterUpdate;
exports.afterMount = afterMount;

var _magicVirtualElement = require('magic-virtual-element');

var _magicVirtualElement2 = _interopRequireDefault(_magicVirtualElement);

var _xtend = require('xtend');

var _xtend2 = _interopRequireDefault(_xtend);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var name = exports.name = 'Swiper';
var Swiper = null;

function initialState(props) {
  return {
    swiper: null
  };
}

function _prevClick(e, _ref, setState) {
  var state = _ref.state;

  if (!state.swiper) {
    return;
  }

  state.swiper.slidePrev();
}

function _nextClick(e, _ref2, setState) {
  var state = _ref2.state;

  if (!state.swiper) {
    return;
  }

  state.swiper.slideNext();
}

function render(_ref3) {
  var props = _ref3.props;
  var state = _ref3.state;

  var innerContent = props.children.map(function (el, index) {
    return (0, _magicVirtualElement2.default)(
      'div',
      { 'class': 'swiper__slide' },
      el
    );
  });

  var nextClick = props.onNextClick || _nextClick;
  var prevClick = props.onPrevClick || _prevClick;

  return (0, _magicVirtualElement2.default)(
    'div',
    null,
    (0, _magicVirtualElement2.default)(
      'div',
      { 'class': 'swiper' },
      (0, _magicVirtualElement2.default)(
        'div',
        { 'class': 'swiper__inner' },
        innerContent
      )
    ),
    (0, _magicVirtualElement2.default)('div', { 'class': 'swiper__arrow swiper__arrow-left', onClick: prevClick }),
    (0, _magicVirtualElement2.default)('div', { 'class': 'swiper__arrow swiper__arrow-right', onClick: nextClick })
  );
}

function afterRender(_ref4, el) {
  var state = _ref4.state;
  var swiper = state.swiper;

  if (swiper) {
    swiper.onResize();
  }
}

function afterUpdate(_ref5) {
  var swiper = _ref5.state.swiper;
  var activeSlide = _ref5.props.activeSlide;

  if (swiper && typeof activeSlide === 'number') {
    swiper.slideTo(activeSlide);
  }
}

function afterMount(_ref6, el, setState) {
  var props = _ref6.props;

  var swiper = null;
  if (!Swiper) {
    Swiper = require('swiper');
  }

  function forward(name) {
    return function () {
      if (swiper && props[name]) {
        props[name]({
          activeIndex: swiper.activeIndex,
          clickedIndex: swiper.clickedIndex
        });
      }
    };
  }

  var opts = (0, _xtend2.default)(props, {
    wrapperClass: 'swiper__inner',
    slideClass: 'swiper__slide',
    slideActiveClass: 'swiper__slide__active',
    slideVisibleClass: 'swiper__slide__visible',
    slideDuplicateClass: 'swiper__slide__duplicate',
    slideNextClass: 'swiper__slide__next',
    slidePrevClass: 'swiper__slide__prev',
    onSlideChangeStart: forward('onSlideChangeStart'),
    onSlideChangeEnd: forward('onSlideChangeEnd'),
    onTransitionStart: forward('onTransitionStart'),
    onTransitionEnd: forward('onTransitionEnd'),
    slideToClickedSlide: props.slideToClickedSlide,
    mousewheelControl: props.mousewheelControl,
    mousewheelForceToAxis: props.mousewheelForceToAxis,
    onClick: forward('onClick'),
    centeredSlides: props.centeredSlides || undefined,
    slidesPerView: props.slidesPerView || undefined,
    initialSlide: props.activeSlide || 0
  });

  swiper = new Swiper(el.querySelector('.swiper'), opts);

  setState({
    swiper: swiper
  });
}

exports.default = { initialState: initialState, render: render, afterRender: afterRender, afterMount: afterMount, afterUpdate: afterUpdate };